#!/bin/sh
WGET_OPTS="--certificate /mnt/shadow/client-certificate.pem"
get_remote_file()
# $1 filename
{
	logger -t "update-script" -p daemon.info "Extractng $1..."
	CMD="/usr/bin/wget ${WGET_OPTS} $1 -N"
	echo "$CMD"
	$CMD
	if [ "$?" -eq "0" ]; then
		logger -t "update-script" -p daemon.info "Extracting $1 is OK"
		return 0
	else
		logger -t "update-script" -p daemon.err "Upload failed. Check $1 for connection problems"
		exit 1
	fi
}

#set -e
 
scriptname=$(basename $0)
lock="/var/run/${scriptname}"

exec 200>$lock
flock -n 200 || exit 1
if [ -f /tmp/playlist_vars ]; then
	. /tmp/playlist_vars
else
	logger -t "$0" -p daemon.warn "File /tmp/playlist_vars does not exist."
    	echo "File /tmp/playlist_vars does not exist"
	SERVERFILE="/playlist.zip"

fi

MUSICDIR=$(uci get application.playlist.local_folder)
SERVERURL=$(uci get application.playlist.server_url)
URL="${SERVERURL}${SERVERFILE}"
ETAG=$(uci get application.playlist.etag)
ZIPNAME=$(basename ${SERVERFILE})

if grep -qs /mnt/data /proc/mounts; then
	if [ ! -d ${MUSICDIR} ]; then
		echo "Folder ${MUSICDIR} does not exist"
		rm -rf ${MUSICDIR}
		echo "Creating ${MUSICDIR}"
		mkdir -p ${MUSICDIR}
	fi

	if [ -z "${NEWETAG}" ]; then
		NEWETAG=`wget -S --spider ${URL} 2>&1 | grep "Last-Modified:" | sed -e 's/Last-Modified://g' | sed -e 's/^[ \t]*//'| sed 's/ /_/g'` 
		echo "NEWETAG=[${NEWETAG}]"	
	fi

	if [ "$ETAG" == "$NEWETAG" ]
	then
		echo "No new music data detected. Quiting."
		logger -t "$0" -p daemon.info "No new music data detected. Quiting."
		exit 0
	fi


	echo "Downloading $URL to ${MUSICDIR}..."
	cd /mnt/data/
	get_remote_file ${URL}

	du ${MUSICDIR}
	echo "Cleaning 	${MUSICDIR}"
	if [ -z "$(ls -A ${MUSICDIR})" ]; then
   		echo "${MUSICDIR} is empty"
	else
		rm ${MUSICDIR}*
		if [ "$?" -ne "0" ]; then
			echo "Music dir empty or something went wrong"
			rm -rf ${MUSICDIR}
			rm /mnt/data/${ZIPNAME}
			exit 1
		fi
	fi
	du ${MUSICDIR}
	logger -t "$0" -p daemon.info "Extractng music zip ${SERVERFILE}..."
	unzip -n ${ZIPNAME} -d ${MUSICDIR} 
	if [ "$?" -eq "0" ]; then
		logger -t "$0" -p daemon.info "Extraction went OK. Saving ETAG and cleaning /mnt/data/${ZIPNAME}..."
		uci set application.playlist.server_file=$SERVERFILE
		uci set application.playlist.etag=$NEWETAG
		uci commit
		rm /mnt/data/${ZIPNAME}
	else
		logger -t "$0" -p daemon.err "Extraction of /mnt/data/${ZIPNAME} FAILED"
		exit 1
	fi
else
	logger -t "$0" -p daemon.warn "No data partion on SD card found. FW will not work properly. Skipping Music update!"	
fi
echo DONE
logger -t "$0" -p daemon.info "DONE"
